/*
 AVR Soft I2C Master - Example for I2C EEPROMs
 Version: 1.1
 Author: Alex from insideGadgets (www.insidegadgets.com)
 Created: 12/02/2012
 Last Modified: 26/12/2013
 
 A software implementation of I2C/TWI Master using code from http://forums.adafruit.com/viewtopic.php?f=25&t=13722
 
 Modifications:
 - Made to work directly with AVR (De-Arduino existing code)
 - Changed from C++ to C
 - Added soft_i2c_eeprom_read_byte and soft_i2c_eeprom_write_byte
 
 */

//                  +-\/-+
// Ain0 (D 5) PB5  1|o   |8  Vcc
// Ain3 (D 3) PB3  2|    |7  PB2 (D 2) Ain1
// Ain2 (D 4) PB4  3|    |6  PB1 (D 1) pwm1
//            GND  4|    |5  PB0 (D 0) pwm0
//                  +----+

#define F_CPU 1000000

#define TWI_SDA_PIN PB0
#define TWI_SCL_PIN PB3

#define ledPin (1<<PB2)
#define EEPROM_ADDR 0x50

#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/sleep.h>
#include <util/delay.h>
#include "setup.c"

int main(void) {
	sei(); // Turn on interrupts
	DDRB |= ledPin;
	
	byte address = 0;
	byte writeByte = 170;
	byte readByte = 0;
	
	SoftI2cMasterInit();
	
	// Write 1 byte to the EEPROM
	soft_i2c_eeprom_write_byte(EEPROM_ADDR, address, writeByte);
	
	// Read 1 byte from the EEPROM
	readByte = soft_i2c_eeprom_read_byte(EEPROM_ADDR, address);
	
	// Blink LED if received byte matches written byte
	if (readByte == writeByte) {
		PORTB |= ledPin;
		_delay_ms(1000);
		PORTB &= ~ledPin;
		_delay_ms(1000);
	}
	
	SoftI2cMasterDeInit();
	
	while(1);
	
	return 0;
}

